==> catppuccin_jupyterlab-0.1.0.tar.gz: catppuccin_jupyterlab-0.1.0/README.md <==
<h3 align="center">
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/logos/exports/1544x1544_circle.png" width="100" alt="Logo"/><br/>
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/misc/transparent.png" height="30" width="0px"/>
	Catppuccin for <a href="https://github.com/jupyterlab/jupyterlab">JupyterLab</a>
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/misc/transparent.png" height="30" width="0px"/>
</h3>

<p align="center">
	<a href="https://github.com/gabrielmagno/jupyterlab/stargazers"><img src="https://img.shields.io/github/stars/gabrielmagno/jupyterlab?colorA=363a4f&colorB=b7bdf8&style=for-the-badge"></a>
	<a href="https://github.com/gabrielmagno/jupyterlab/issues"><img src="https://img.shields.io/github/issues/gabrielmagno/jupyterlab?colorA=363a4f&colorB=f5a97f&style=for-the-badge"></a>
	<a href="https://github.com/gabrielmagno/jupyterlab/contributors"><img src="https://img.shields.io/github/contributors/gabrielmagno/jupyterlab?colorA=363a4f&colorB=a6da95&style=for-the-badge"></a>
</p>

<p align="center">
	<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/preview.webp"/>
</p>

## Previews

<details>
<summary>🌻 Latte</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/latte.webp"/>
</details>
<details>
<summary>🪴 Frappé</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/frappe.webp"/>
</details>
<details>
<summary>🌺 Macchiato</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/macchiato.webp"/>
</details>
<details>
<summary>🌿 Mocha</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/mocha.webp"/>
</details>

## Usage

1. Install the JupyterLab extension: `pip install catppuccin-jupyterlab`.
2. Start/restart JupyterLab (`jupyter lab`). If it is already opened, you can reload it by executing "Reset Application State" in the Command Palette (`Ctrl + Shift + C`).
3. Go to the `Settings > Theme` menu option and choose the desired flavor.

## Customization

### Brand Color

It is possible to choose any of the Catppucin colors as your "brand" color. The default is `mauve`, but you can choose your favorite to make it your way!

<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/mocha-brand.webp"/>

You can specify the colors by going to the `Settings > Settings Editor` (or `Ctrl + ,`), going to the `Theme - Catppuccin` section, then choosing your desired color in the lists of the dropdown menu.

<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/settings.webp"/>

Alternatively, you can specify the json with the settings:
```json
{
    "brandColor": "mauve",
    "accentColor": "green"
}
```

*NOTE*: besides the "brand" color it is also possible to set the "accent" color (default is `green`), but it rarelly appears in the JupyterLab interface.

## 💝 Thanks to

- [Gabriel Magno](https://github.com/gabrielmagno)

&nbsp;

<p align="center">
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/footers/gray0_ctp_on_line.svg?sanitize=true" />
</p>

<p align="center">
	Copyright &copy; 2021-present <a href="https://github.com/catppuccin" target="_blank">Catppuccin Org</a>
</p>

<p align="center">
	<a href="https://github.com/catppuccin/catppuccin/blob/main/LICENSE"><img src="https://img.shields.io/static/v1.svg?style=for-the-badge&label=License&message=MIT&logoColor=d9e0ee&colorA=363a4f&colorB=b7bdf8"/></a>
</p>

==> catppuccin_jupyterlab-0.1.3.tar.gz: catppuccin_jupyterlab-0.1.3/README.md <==
<h3 align="center">
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/logos/exports/1544x1544_circle.png" width="100" alt="Logo"/><br/>
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/misc/transparent.png" height="30" width="0px"/>
	Catppuccin for <a href="https://github.com/jupyterlab/jupyterlab">JupyterLab</a>
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/misc/transparent.png" height="30" width="0px"/>
</h3>

<p align="center">
	<a href="https://github.com/gabrielmagno/jupyterlab/stargazers"><img src="https://img.shields.io/github/stars/gabrielmagno/jupyterlab?colorA=363a4f&colorB=b7bdf8&style=for-the-badge"></a>
	<a href="https://github.com/gabrielmagno/jupyterlab/issues"><img src="https://img.shields.io/github/issues/gabrielmagno/jupyterlab?colorA=363a4f&colorB=f5a97f&style=for-the-badge"></a>
	<a href="https://github.com/gabrielmagno/jupyterlab/contributors"><img src="https://img.shields.io/github/contributors/gabrielmagno/jupyterlab?colorA=363a4f&colorB=a6da95&style=for-the-badge"></a>
</p>

<p align="center">
	<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/preview.webp"/>
</p>

## Previews

<details>
<summary>🌻 Latte</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/latte.webp"/>
</details>
<details>
<summary>🪴 Frappé</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/frappe.webp"/>
</details>
<details>
<summary>🌺 Macchiato</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/macchiato.webp"/>
</details>
<details>
<summary>🌿 Mocha</summary>
<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/mocha.webp"/>
</details>

## Usage

1. Install the JupyterLab extension: `pip install catppuccin-jupyterlab`.
2. Start/restart JupyterLab (`jupyter lab`). If it is already opened, you can reload it by executing "Reset Application State" in the Command Palette (`Ctrl + Shift + C`).
3. Go to the `Settings > Theme` menu option and choose the desired flavor.

## Customization

### Brand Color

It is possible to choose any of the Catppucin colors as your "brand" color. The default is `mauve`, but you can choose your favorite to make it your way!

<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/mocha-brand.webp"/>

You can specify the colors by going to the `Settings > Settings Editor` (or `Ctrl + ,`), going to the `Theme - Catppuccin` section, then choosing your desired color in the lists of the dropdown menu.

<img src="https://raw.githubusercontent.com/gabrielmagno/jupyterlab/main/assets/settings.webp"/>

Alternatively, you can specify the json with the settings:
```json
{
    "brandColor": "mauve",
    "accentColor": "green"
}
```

> [!NOTE]
> Besides the "brand" color it is also possible to set the "accent" color (default is green), but it rarely appears in the JupyterLab interface.

## 💝 Thanks to

- [Gabriel Magno](https://github.com/gabrielmagno)

&nbsp;

<p align="center">
	<img src="https://raw.githubusercontent.com/catppuccin/catppuccin/main/assets/footers/gray0_ctp_on_line.svg?sanitize=true" />
</p>

<p align="center">
	Copyright &copy; 2021-present <a href="https://github.com/catppuccin" target="_blank">Catppuccin Org</a>
</p>

<p align="center">
	<a href="https://github.com/catppuccin/catppuccin/blob/main/LICENSE"><img src="https://img.shields.io/static/v1.svg?style=for-the-badge&label=License&message=MIT&logoColor=d9e0ee&colorA=363a4f&colorB=b7bdf8"/></a>
</p>
